@@ -1,3 +1,3 @@
-from EntropySGD.EntropySGD import EntropySGD
+from EntropySGD.EntropySGD import EntropySgd
 from EntropySGD.EntropyAdam import EntropyAdam
 from EntropySGD.History import History
\ No newline at end of file
